@@ -11,7 +11,7 @@ Unless required by applicable law or agreed to in writing, software distributed
  language governing permissions and limitations under the License.
 """
 
-import json
+import copy
 import logging
 import pathlib
 import sys
@@ -39,12 +39,16 @@ def compatibility_layer(spec):
     # Make all response codes be string
     for path_name, methods_available in spec.get('paths', {}).items():
         for method_name, method_def in methods_available.items():
-            if method_name == 'parameters':
+            if (method_name == 'parameters' or not isinstance(
+                    method_def, dict)):
                 continue
+
             response_definitions = {}
-            for response_code, response_def in method_def.get('responses', {}).items():
+            for response_code, response_def in method_def.get(
+                    'responses', {}).items():
                 response_definitions[str(response_code)] = response_def
-                method_def['responses'] = response_definitions
+
+            method_def['responses'] = response_definitions
     return spec
 
 
@@ -87,7 +91,10 @@ class Api(object):
 
         logger.debug('Read specification', extra=self.specification)
 
-        validate_spec(compatibility_layer(self.specification))
+        self.specification = compatibility_layer(self.specification)
+        # Avoid validator having ability to modify specification
+        spec = copy.deepcopy(self.specification)
+        validate_spec(spec)
 
         # https://github.com/swagger-api/swagger-spec/blob/master/versions/2.0.md#fixed-fields
         # If base_url is not on provided then we try to read it from the swagger.yaml or use / by default
@@ -214,7 +221,9 @@ class Api(object):
         """
         logger.debug('Adding swagger.json: %s/swagger.json', self.base_url)
         endpoint_name = "{name}_swagger_json".format(name=self.blueprint.name)
-        self.blueprint.add_url_rule('/swagger.json', endpoint_name, lambda: json.dumps(self.specification))
+        self.blueprint.add_url_rule('/swagger.json',
+                                    endpoint_name,
+                                    lambda: flask.jsonify(self.specification))
 
     def add_swagger_ui(self):
         """
