@@ -11,9 +11,9 @@ Unless required by applicable law or agreed to in writing, software distributed
  language governing permissions and limitations under the License.
 """
 
+import collections
 import copy
 import functools
-import itertools
 import logging
 import sys
 
@@ -74,7 +74,7 @@ def validate_type(param, value, parameter_type, parameter_name=None):
                 converted = make_type(part, param["items"]["type"])
             except (ValueError, TypeError):
                 converted = part
-        converted_parts.append(converted)
+            converted_parts.append(converted)
         return converted_parts
     else:
         try:
@@ -126,7 +126,8 @@ class RequestBodyValidator(object):
         try:
             validate(data, self.schema, format_checker=draft4_format_checker)
         except ValidationError as exception:
-            logger.error("%s validation error: %s" % (flask.request.url, exception))
+            logger.error("{url} validation error: {error}".format(url=flask.request.url,
+                                                                  error=exception))
             return problem(400, 'Bad Request', str(exception))
 
         return None
@@ -149,7 +150,8 @@ class ResponseBodyValidator(object):
         try:
             validate(data, self.schema, format_checker=draft4_format_checker)
         except ValidationError as exception:
-            logger.error("%s validation error: %s" % (flask.request.url, exception))
+            logger.error("{url} validation error: {error}".format(url=flask.request.url,
+                                                                  error=exception))
             six.reraise(*sys.exc_info())
 
         return None
@@ -157,7 +159,9 @@ class ResponseBodyValidator(object):
 
 class ParameterValidator(object):
     def __init__(self, parameters):
-        self.parameters = {k: list(g) for k, g in itertools.groupby(parameters, key=lambda p: p['in'])}
+        self.parameters = collections.defaultdict(list)
+        for p in parameters:
+            self.parameters[p['in']].append(p)
 
     @staticmethod
     def validate_parameter(parameter_type, value, param):
